model

package
v0.0.0-...-3bed8a6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 27, 2025 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

Functions

This section is empty.

Types

type AWSOperation

type AWSOperation struct {
	Resource string          `json:"resource"`
	Actions  []string        `json:"actions"`
	SrcIP    *string         `json:"srcIp,omitempty"`
	IamRole  *string         `json:"iamRole,omitempty"`
	Client   *NamespacedName `json:"client,omitempty"`
}

type AWSOperationResults

type AWSOperationResults []AWSOperation

func (AWSOperationResults) Length

func (c AWSOperationResults) Length() int

type AzureOperation

type AzureOperation struct {
	Scope           string   `json:"scope"`
	Actions         []string `json:"actions"`
	DataActions     []string `json:"dataActions"`
	ClientName      string   `json:"clientName"`
	ClientNamespace string   `json:"clientNamespace"`
}

type AzureOperationResults

type AzureOperationResults []AzureOperation

func (AzureOperationResults) Length

func (c AzureOperationResults) Length() int

type CaptureResults

type CaptureResults struct {
	Results []RecordedDestinationsForSrc `json:"results"`
}

func (CaptureResults) Length

func (c CaptureResults) Length() int

type CaptureTCPResults

type CaptureTCPResults struct {
	Results []RecordedDestinationsForSrc `json:"results"`
}

func (CaptureTCPResults) Length

func (c CaptureTCPResults) Length() int

type Destination

type Destination struct {
	Destination     string    `json:"destination"`
	DestinationIP   *string   `json:"destinationIP,omitempty"`
	DestinationPort *int64    `json:"destinationPort,omitempty"`
	TTL             *int64    `json:"TTL,omitempty"`
	LastSeen        time.Time `json:"lastSeen"`
	SrcPorts        []int64   `json:"srcPorts,omitempty"`
}

type GCPOperation

type GCPOperation struct {
	Resource    string          `json:"resource"`
	Permissions []string        `json:"permissions"`
	SrcIP       *string         `json:"srcIp,omitempty"`
	Client      *NamespacedName `json:"client,omitempty"`
}

type GCPOperationResults

type GCPOperationResults []GCPOperation

func (GCPOperationResults) Length

func (c GCPOperationResults) Length() int

type GroupVersionKind

type GroupVersionKind struct {
	Group   *string `json:"group,omitempty"`
	Version string  `json:"version"`
	Kind    string  `json:"kind"`
}

func GroupVersionKindFromKubeGVK

func GroupVersionKindFromKubeGVK(kind schema.GroupVersionKind) *GroupVersionKind

type HTTPMethod

type HTTPMethod string
const (
	HTTPMethodGet     HTTPMethod = "GET"
	HTTPMethodPost    HTTPMethod = "POST"
	HTTPMethodPut     HTTPMethod = "PUT"
	HTTPMethodDelete  HTTPMethod = "DELETE"
	HTTPMethodOptions HTTPMethod = "OPTIONS"
	HTTPMethodTrace   HTTPMethod = "TRACE"
	HTTPMethodPatch   HTTPMethod = "PATCH"
	HTTPMethodConnect HTTPMethod = "CONNECT"
	HTTPMethodAll     HTTPMethod = "ALL"
)

func (HTTPMethod) IsValid

func (e HTTPMethod) IsValid() bool

func (HTTPMethod) MarshalGQL

func (e HTTPMethod) MarshalGQL(w io.Writer)

func (HTTPMethod) MarshalJSON

func (e HTTPMethod) MarshalJSON() ([]byte, error)

func (HTTPMethod) String

func (e HTTPMethod) String() string

func (*HTTPMethod) UnmarshalGQL

func (e *HTTPMethod) UnmarshalGQL(v any) error

func (*HTTPMethod) UnmarshalJSON

func (e *HTTPMethod) UnmarshalJSON(b []byte) error

type HTTPResource

type HTTPResource struct {
	Path    string       `json:"path"`
	Methods []HTTPMethod `json:"methods,omitempty"`
}

type IdentityResolutionData

type IdentityResolutionData struct {
	Host                  *string                   `json:"host,omitempty"`
	PodHostname           *string                   `json:"podHostname,omitempty"`
	ProcfsHostname        *string                   `json:"procfsHostname,omitempty"`
	Port                  *int64                    `json:"port,omitempty"`
	IsService             *bool                     `json:"isService,omitempty"`
	Uptime                *string                   `json:"uptime,omitempty"`
	LastSeen              *string                   `json:"lastSeen,omitempty"`
	ExtraInfo             *string                   `json:"extraInfo,omitempty"`
	HasLinkerdSidecar     *bool                     `json:"hasLinkerdSidecar,omitempty"`
	TCPDestResolveFixData *TCPDestResolveBugfixData `json:"tcpDestResolveFixData,omitempty"`
}

type Intent

type Intent struct {
	Client         *OtterizeServiceIdentity `json:"client"`
	Server         *OtterizeServiceIdentity `json:"server"`
	Type           *IntentType              `json:"type,omitempty"`
	ResolutionData *string                  `json:"resolutionData,omitempty"`
	KafkaTopics    []KafkaConfig            `json:"kafkaTopics,omitempty"`
	HTTPResources  []HTTPResource           `json:"httpResources,omitempty"`
	AWSActions     []string                 `json:"awsActions,omitempty"`
}

type IntentType

type IntentType string
const (
	IntentTypeHTTP     IntentType = "HTTP"
	IntentTypeKafka    IntentType = "KAFKA"
	IntentTypeDatabase IntentType = "DATABASE"
	IntentTypeAWS      IntentType = "AWS"
	IntentTypeS3       IntentType = "S3"
)

func (IntentType) IsValid

func (e IntentType) IsValid() bool

func (IntentType) MarshalGQL

func (e IntentType) MarshalGQL(w io.Writer)

func (IntentType) MarshalJSON

func (e IntentType) MarshalJSON() ([]byte, error)

func (IntentType) String

func (e IntentType) String() string

func (*IntentType) UnmarshalGQL

func (e *IntentType) UnmarshalGQL(v any) error

func (*IntentType) UnmarshalJSON

func (e *IntentType) UnmarshalJSON(b []byte) error

type IstioConnection

type IstioConnection struct {
	SrcWorkload          string       `json:"srcWorkload"`
	SrcWorkloadNamespace string       `json:"srcWorkloadNamespace"`
	DstWorkload          string       `json:"dstWorkload"`
	DstServiceName       string       `json:"dstServiceName"`
	DstWorkloadNamespace string       `json:"dstWorkloadNamespace"`
	Path                 string       `json:"path"`
	Methods              []HTTPMethod `json:"methods"`
	LastSeen             time.Time    `json:"lastSeen"`
}

type IstioConnectionResults

type IstioConnectionResults struct {
	Results []IstioConnection `json:"results"`
}

func (IstioConnectionResults) Length

func (c IstioConnectionResults) Length() int

type KafkaConfig

type KafkaConfig struct {
	Name       string           `json:"name"`
	Operations []KafkaOperation `json:"operations,omitempty"`
}

type KafkaMapperResult

type KafkaMapperResult struct {
	SrcIP           string    `json:"srcIp"`
	ServerPodName   string    `json:"serverPodName"`
	ServerNamespace string    `json:"serverNamespace"`
	Topic           string    `json:"topic"`
	Operation       string    `json:"operation"`
	LastSeen        time.Time `json:"lastSeen"`
}

type KafkaMapperResults

type KafkaMapperResults struct {
	Results []KafkaMapperResult `json:"results"`
}

func (KafkaMapperResults) Length

func (c KafkaMapperResults) Length() int

type KafkaOperation

type KafkaOperation string
const (
	KafkaOperationAll             KafkaOperation = "ALL"
	KafkaOperationConsume         KafkaOperation = "CONSUME"
	KafkaOperationProduce         KafkaOperation = "PRODUCE"
	KafkaOperationCreate          KafkaOperation = "CREATE"
	KafkaOperationAlter           KafkaOperation = "ALTER"
	KafkaOperationDelete          KafkaOperation = "DELETE"
	KafkaOperationDescribe        KafkaOperation = "DESCRIBE"
	KafkaOperationClusterAction   KafkaOperation = "CLUSTER_ACTION"
	KafkaOperationDescribeConfigs KafkaOperation = "DESCRIBE_CONFIGS"
	KafkaOperationAlterConfigs    KafkaOperation = "ALTER_CONFIGS"
	KafkaOperationIdempotentWrite KafkaOperation = "IDEMPOTENT_WRITE"
)

func KafkaOpFromText

func KafkaOpFromText(text string) (KafkaOperation, error)

func (KafkaOperation) IsValid

func (e KafkaOperation) IsValid() bool

func (KafkaOperation) MarshalGQL

func (e KafkaOperation) MarshalGQL(w io.Writer)

func (KafkaOperation) MarshalJSON

func (e KafkaOperation) MarshalJSON() ([]byte, error)

func (KafkaOperation) String

func (e KafkaOperation) String() string

func (*KafkaOperation) UnmarshalGQL

func (e *KafkaOperation) UnmarshalGQL(v any) error

func (*KafkaOperation) UnmarshalJSON

func (e *KafkaOperation) UnmarshalJSON(b []byte) error

type Mutation

type Mutation struct {
}

type NamespacedName

type NamespacedName struct {
	Name      string `json:"name"`
	Namespace string `json:"namespace"`
}

type OtterizeServiceIdentity

type OtterizeServiceIdentity struct {
	Name                        string                  `json:"name"`
	Namespace                   string                  `json:"namespace"`
	Labels                      []PodLabel              `json:"labels,omitempty"`
	NameResolvedUsingAnnotation *bool                   `json:"nameResolvedUsingAnnotation,omitempty"`
	ResolutionData              *IdentityResolutionData `json:"resolutionData,omitempty"`
	// If the service identity was resolved from a pod owner, the GroupVersionKind of the pod owner.
	PodOwnerKind *GroupVersionKind `json:"podOwnerKind,omitempty"`
	// If the service identity was resolved from a Kubernetes service, its name.
	KubernetesService *string `json:"kubernetesService,omitempty"`
}

func (OtterizeServiceIdentity) AsNamespacedName

func (identity OtterizeServiceIdentity) AsNamespacedName() types.NamespacedName

type PodLabel

type PodLabel struct {
	Key   string `json:"key"`
	Value string `json:"value"`
}

type Query

type Query struct {
}

type RecordedDestinationsForSrc

type RecordedDestinationsForSrc struct {
	SrcIP        string        `json:"srcIp"`
	SrcHostname  string        `json:"srcHostname"`
	Destinations []Destination `json:"destinations"`
}

type ServerFilter

type ServerFilter struct {
	Name      string `json:"name"`
	Namespace string `json:"namespace"`
}

type ServiceIntents

type ServiceIntents struct {
	Client  *OtterizeServiceIdentity  `json:"client"`
	Intents []OtterizeServiceIdentity `json:"intents"`
}

type SocketScanResults

type SocketScanResults struct {
	Results []RecordedDestinationsForSrc `json:"results"`
}

func (SocketScanResults) Length

func (c SocketScanResults) Length() int

type TCPDestResolveBugfixData

type TCPDestResolveBugfixData struct {
	IsSrcControlPlane bool `json:"isSrcControlPlane"`
	ResolvedUsingIP   bool `json:"resolvedUsingIp"`
}

type TrafficLevelResult

type TrafficLevelResult struct {
	SrcIP     string `json:"srcIP"`
	DstIP     string `json:"dstIP"`
	BytesSent int64  `json:"bytesSent"`
	Flows     int64  `json:"flows"`
}

type TrafficLevelResults

type TrafficLevelResults struct {
	Results []TrafficLevelResult `json:"results"`
}

func (TrafficLevelResults) Length

func (c TrafficLevelResults) Length() int

Jump to